# demo-py

Collecting tools I use to demo in one place.

![Python package](https://github.com/omars-lab/demo-py/workflows/Python%20package/badge.svg)

# Todo
- [ ] Add some real test cases for the puml ...
    * [ ] Need to add examples of how to use them ...
    - [ ] Can maybe make a blog post on this ...
* [ ] Tinker with platuml themes ...
	* [ ] https://the-lum.github.io/puml-themes-gallery/#cerulean-outline
- [ ] Add more charts
- [ ] Add an interactive time bar

# Personal Reminders
- To publish to pypi w/o an alpha version, push a commit with `Publish To PYPI` in its commit message.

# References
https://kapernikov.com/ipywidgets-with-matplotlib/
https://stackoverflow.com/questions/20288711/post-install-script-with-python-setuptools
https://stackoverflow.com/questions/50842160/how-to-display-matplotlib-plots-in-a-jupyter-tab-widget
https://matplotlib.org/gallery/api/barchart.html
https://pandas.pydata.org/pandas-docs/stable/user_guide/style.html

https://blog.emacsos.com/bootstrap-a-python-project.html
* [ ] https://plantuml.com/sitemap